require_relative 'check_api'
require_relative 'info_api'
require_relative 'search_api'

# Class provided to maintain a connection to the API
class Epitech::Api::Connection
  include Epitech::Api

  include Epitech::Api::CheckApi
  include Epitech::Api::InfoApi
  include Epitech::Api::SearchApi

  # Constructor
  # @param login  [String]  Your ionis login
  # @param pwd    [String]  Your ionis password
  # @return       [Boolean] True if the connection was successful (Raise a Epitech::Api::Errors::AuthFail otherwise)
  def initialize(login, pwd)
    @login = login
    @pwd = pwd
    connect!
  end

  # Overloading of Epitech::Api::call_api, will use instance variables
  # for auth_login and auth_password
  def call_api(opts={})
    opts[:auth_login] ||= @login
    opts[:auth_password] ||= @pwd
    super(opts)
  end

  # Try to connect to the API with the instance variables
  def connect!
    @connected = check_auth
  end

  # @return True if the connection is established, false otherwise
  def is_connected?
    @connected
  end

end